# locked-out
A data persistent python cli with timers (to lock in), note taking and ascii art :]
# Install
run the following command:
```
pip install lockedout==0.0.1
```
# Use 
run 'lockedout' in any folder, and add any of the following flags. Use no flags to print a similar help message to the following message.
  -h, --help           show this help message and exit
  -l, --lockin [DURATION]  Set a reminder to lock in in X minutes
  -n, --note '[NOTE]'    quick note! updates only to the last note. Use -n again to display the note.
  -a, --art [ART]        Change ASCII art to [bat,bird,cat,dolphin,whale,shark]